@@ -1,9 +1,8 @@
 """Program defaults."""
 
+import logging
 import os
 
-import log
-
 
 # Cache settings
 CACHE = os.path.expanduser(os.getenv('GITMAN_CACHE', "~/.gitcache"))
@@ -14,12 +13,8 @@ DEFAULT_LOGGING_FORMAT = "%(message)s"
 LEVELED_LOGGING_FORMAT = "%(levelname)s: %(message)s"
 VERBOSE_LOGGING_FORMAT = "[%(levelname)-8s] %(message)s"
 VERBOSE2_LOGGING_FORMAT = "[%(levelname)-8s] (%(name)s @%(lineno)4d) %(message)s"
-QUIET_LOGGING_LEVEL = log.ERROR
-DEFAULT_LOGGING_LEVEL = log.WARNING
-VERBOSE_LOGGING_LEVEL = log.INFO
-VERBOSE2_LOGGING_LEVEL = log.DEBUG
+QUIET_LOGGING_LEVEL = logging.ERROR
+DEFAULT_LOGGING_LEVEL = logging.WARNING
+VERBOSE_LOGGING_LEVEL = logging.INFO
+VERBOSE2_LOGGING_LEVEL = logging.DEBUG
 LOGGING_DATEFMT = "%Y-%m-%d %H:%M"
-
-# 3rd party settings
-YORM_LOGGING_LEVEL = log.WARNING
-SH_LOGGING_LEVEL = log.WARNING
